use std::path::PathBuf;

use super::{Relocatable, Section};
use crate::error::Error;

pub trait Output<R>
where
    R: Relocatable
{
    fn process_section(&mut self, section: Section) -> Result<(), Error>;

    fn finalize(self, objects: &Vec<R>) -> Result<PathBuf, Error>;
}

pub struct DummyOutput;

impl<R> Output<R> for DummyOutput
where
    R: Relocatable
{
    fn process_section(&mut self, section: Section) -> Result<(), Error> {
        eprintln!("Appending section: {}", section);
        Ok(())
    }

    fn finalize(self, objects: &Vec<R>) -> Result<PathBuf, Error> {
        todo!();
    }
}
