use std::path::Path;
use std::{convert::TryFrom, fmt::Display, path::PathBuf};

use crate::error::Error;

use super::Section;

pub type BSI<'iter> = Box<dyn Iterator<Item = Result<Section, Error>> + 'iter>;
/// Contains all the needed getters to construct a final
/// mushed and relocated executable from an object file
pub trait Relocatable: Display + TryFrom<PathBuf, Error = Error> {
    fn origin(&self) -> &Path; // not same as section's path since this one's supposed to be cannonical

    fn sections<'iter>(self: &'iter Self) -> BSI<'iter>;

    fn section_data(&self, section_index: usize) -> Result<&[u8], Error>;
}
